@@ -16,11 +16,12 @@ import typing
 
 try:
     BaseExceptionGroup = BaseExceptionGroup
-except NameError:  # pragma: no cover
-    try:
-        from exceptiongroup import BaseExceptionGroup as BaseExceptionGroup  # for mypy
-    except ImportError:
-        BaseExceptionGroup = ()  # valid in isinstance and except clauses!
+    ExceptionGroup = ExceptionGroup  # pragma: no cover
+except NameError:
+    from exceptiongroup import (
+        BaseExceptionGroup as BaseExceptionGroup,
+        ExceptionGroup as ExceptionGroup,
+    )
 
 PYPY = platform.python_implementation() == "PyPy"
 WINDOWS = platform.system() == "Windows"
@@ -87,11 +88,16 @@ def get_type_hints(thing):
         if hasattr(thing, "__signature__"):
             # It is possible for the signature and annotations attributes to
             # differ on an object due to renamed arguments.
+            from hypothesis.internal.reflection import get_signature
             from hypothesis.strategies._internal.types import is_a_type
 
             vkinds = (inspect.Parameter.VAR_POSITIONAL, inspect.Parameter.VAR_KEYWORD)
-            for p in inspect.signature(thing).parameters.values():
-                if p.kind not in vkinds and is_a_type(p.annotation):
+            for p in get_signature(thing).parameters.values():
+                if (
+                    p.kind not in vkinds
+                    and is_a_type(p.annotation)
+                    and p.annotation is not p.empty
+                ):
                     if p.default is None:
                         hints[p.name] = typing.Optional[p.annotation]
                     else:
